pub struct MemoryBackend { /* private fields */ }Expand description
In-memory storage backend.
This is the default storage backend that keeps all data in memory. Data is lost when the process exits unless WAL is enabled.
Implementations
Sourceimpl MemoryBackend
impl MemoryBackend
Sourcepub fn new() -> Result<Self, AllocError>
pub fn new() -> Result<Self, AllocError>